==> jc-1.4.0.tar.gz: javax/swing/text/JTextComponent__24KeyBinding.h <==
// public class javax.swing.text.JTextComponent$KeyBinding

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2d1c0777785cdccb javax_swing_text_JTextComponent__24KeyBinding

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_JTextComponent__24KeyBinding_H_
#define _JC_javax_swing_text_JTextComponent__24KeyBinding_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_KeyStroke$object;

// Typedefs
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_refs	_jc_javax_swing_text_JTextComponent__24KeyBinding$sub_refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_nonrefs	_jc_javax_swing_text_JTextComponent__24KeyBinding$sub_nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$refs	_jc_javax_swing_text_JTextComponent__24KeyBinding$refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$nonrefs	_jc_javax_swing_text_JTextComponent__24KeyBinding$nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$object	_jc_javax_swing_text_JTextComponent__24KeyBinding$object;

typedef const struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vmethods	_jc_javax_swing_text_JTextComponent__24KeyBinding$vmethods;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vtable	_jc_javax_swing_text_JTextComponent__24KeyBinding$vtable;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vtype	_jc_javax_swing_text_JTextComponent__24KeyBinding$vtype;

// Constructors
extern void _jc_javax_swing_text_JTextComponent__24KeyBinding$method$_init$22dd6703e48d28c8(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeyBinding$object *, struct _jc_javax_swing_KeyStroke$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vmethods {
};

// Vtable
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_JTextComponent__24KeyBinding$vmethods	javax_swing_text_JTextComponent__24KeyBinding;
};

// Vtype
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vtype {
	_jc_type			type;
	_jc_javax_swing_text_JTextComponent__24KeyBinding$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_refs {
	struct _jc_javax_swing_KeyStroke$object	*key;
	struct _jc_java_lang_String$object	*actionName;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$refs {
    _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_refs	javax_swing_text_JTextComponent__24KeyBinding;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_nonrefs	javax_swing_text_JTextComponent__24KeyBinding;
};

// Object instance structure
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$object {
	_jc_javax_swing_text_JTextComponent__24KeyBinding$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_JTextComponent__24KeyBinding$vtype	*vtype;
	_jc_javax_swing_text_JTextComponent__24KeyBinding$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_JTextComponent__24KeyBinding$vtype _jc_javax_swing_text_JTextComponent__24KeyBinding$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_JTextComponent__24KeyBinding, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_JTextComponent__24KeyBinding$class_object;

#endif	/* _JC_javax_swing_text_JTextComponent__24KeyBinding_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/JTextComponent__24KeyBinding.h <==
// public class javax.swing.text.JTextComponent$KeyBinding

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2d1c0777785cdccb javax_swing_text_JTextComponent__24KeyBinding

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_JTextComponent__24KeyBinding_H_
#define _JC_javax_swing_text_JTextComponent__24KeyBinding_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_KeyStroke$object;

// Typedefs
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_refs	_jc_javax_swing_text_JTextComponent__24KeyBinding$sub_refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_nonrefs	_jc_javax_swing_text_JTextComponent__24KeyBinding$sub_nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$refs	_jc_javax_swing_text_JTextComponent__24KeyBinding$refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$nonrefs	_jc_javax_swing_text_JTextComponent__24KeyBinding$nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeyBinding$object	_jc_javax_swing_text_JTextComponent__24KeyBinding$object;

typedef const struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vmethods	_jc_javax_swing_text_JTextComponent__24KeyBinding$vmethods;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vtable	_jc_javax_swing_text_JTextComponent__24KeyBinding$vtable;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vtype	_jc_javax_swing_text_JTextComponent__24KeyBinding$vtype;

// Constructors
extern void _jc_javax_swing_text_JTextComponent__24KeyBinding$method$_init$22dd6703e48d28c8(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeyBinding$object *, struct _jc_javax_swing_KeyStroke$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vmethods {
};

// Vtable
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_JTextComponent__24KeyBinding$vmethods	javax_swing_text_JTextComponent__24KeyBinding;
};

// Vtype
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$vtype {
	_jc_type			type;
	_jc_javax_swing_text_JTextComponent__24KeyBinding$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_refs {
	struct _jc_javax_swing_KeyStroke$object	*key;
	struct _jc_java_lang_String$object	*actionName;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$refs {
    _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_refs	javax_swing_text_JTextComponent__24KeyBinding;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_JTextComponent__24KeyBinding$sub_nonrefs	javax_swing_text_JTextComponent__24KeyBinding;
};

// Object instance structure
struct _jc_javax_swing_text_JTextComponent__24KeyBinding$object {
	_jc_javax_swing_text_JTextComponent__24KeyBinding$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_JTextComponent__24KeyBinding$vtype	*vtype;
	_jc_javax_swing_text_JTextComponent__24KeyBinding$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_JTextComponent__24KeyBinding$vtype _jc_javax_swing_text_JTextComponent__24KeyBinding$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_JTextComponent__24KeyBinding, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_JTextComponent__24KeyBinding$class_object;

#endif	/* _JC_javax_swing_text_JTextComponent__24KeyBinding_H_ */
